summaryrefslogtreecommitdiff
path: root/gtk/gtkwindowhandle.c
diff options
context:
space:
mode:
Diffstat (limited to 'gtk/gtkwindowhandle.c')
-rw-r--r--gtk/gtkwindowhandle.c7
1 files changed, 6 insertions, 1 deletions
diff --git a/gtk/gtkwindowhandle.c b/gtk/gtkwindowhandle.c
index 18919becac..5a6beeb273 100644
--- a/gtk/gtkwindowhandle.c
+++ b/gtk/gtkwindowhandle.c
@@ -48,7 +48,11 @@
*
* # CSS nodes
*
* #GtkWindowHandle has a single CSS node with the name windowhandle.
*/
struct _GtkWindowHandle {
@@ -550,6 +554,7 @@ gtk_window_handle_class_init (GtkWindowHandleClass *klass)
gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
gtk_widget_class_set_css_name (widget_class, I_("windowhandle"));
+ gtk_widget_class_set_accessible_role (widget_class, GTK_ACCESSIBLE_ROLE_GROUP);
}
static void
@@ -48,7 +48,11 @@
* # CSS nodes
*
- * #GtkWindowHandle has a single CSS node with the name windowhandle.
+ * #GtkWindowHandle has a single CSS node with the name `windowhandle`.
+ *
+ * # Accessibility
+ *
+ * GtkWindowHandle uses the %GTK_ACCESSIBLE_ROLE_GROUP role.
*/
struct _GtkWindowHandle {